==> dojo-1.10.6.tgz: package/cldr/nls/mk/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E h:mm a",
	"days-standAlone-short": [
		"нед.",
		"пон.",
		"вто.",
		"сре.",
		"чет.",
		"пет.",
		"саб."
	],
	"months-format-narrow": [
		"ј",
		"ф",
		"м",
		"а",
		"м",
		"ј",
		"ј",
		"а",
		"с",
		"о",
		"н",
		"д"
	],
	"field-second-relative+0": "сега",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "Ден во неделата",
	"dateFormatItem-yQQQ": "QQQ y 'г'.",
	"dateFormatItem-yMEd": "E, d.M.y",
	"field-wed-relative+0": "оваа среда",
	"field-wed-relative+1": "следната среда",
	"dateFormatItem-GyMMMEd": "E, dd MMM y 'г'. G",
	"dateFormatItem-MMMEd": "E d MMM",
	"eraNarrow": [
		"пр.н.е.",
		"н.е."
	],
	"field-tue-relative+-1": "минатиот вторник",
	"days-format-short": [
		"нед.",
		"пон.",
		"3",
		"сре.",
		"чет.",
		"пет.",
		"7"
	],
	"dateFormat-long": "dd MMMM y 'г'.",
	"field-fri-relative+-1": "минатиот петок",
	"field-wed-relative+-1": "минатата среда",
	"months-format-wide": [
		"јануари",
		"февруари",
		"март",
		"април",
		"мај",
		"јуни",
		"јули",
		"август",
		"септември",
		"октомври",
		"ноември",
		"декември"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "попладне",
	"dateFormat-full": "EEEE, dd MMMM y 'г'.",
	"field-thu-relative+-1": "минатиот четврток",
	"dateFormatItem-Md": "d.M",
	"dateFormatItem-yMd": "d.M.y",
	"field-era": "Ера",
	"dateFormatItem-yM": "M.y",
	"months-standAlone-wide": [
		"јануари",
		"февруари",
		"март",
		"април",
		"мај",
		"јуни",
		"јули",
		"август",
		"септември",
		"октомври",
		"ноември",
		"декември"
	],
	"timeFormat-short": "HH:mm",
	"quarters-format-wide": [
		"прво тромесечје",
		"второ тромесечје",
		"трето тромесечје",
		"четврто тромесечје"
	],
	"dateFormatItem-yQQQQ": "QQQQ y 'г'.",
	"timeFormat-long": "HH:mm:ss z",
	"field-year": "година",
	"dateFormatItem-yMMM": "MMM y 'г'.",
	"field-hour": "Час",
	"months-format-abbr": [
		"јан.",
		"фев.",
		"мар.",
		"апр.",
		"мај",
		"јун.",
		"јул.",
		"авг.",
		"септ.",
		"окт.",
		"ноем.",
		"дек."
	],
	"field-sat-relative+0": "оваа сабота",
	"field-sat-relative+1": "следната сабота",
	"timeFormat-full": "HH:mm:ss zzzz",
	"field-day-relative+0": "Денес",
	"field-thu-relative+0": "овој четврток",
	"field-day-relative+1": "утре",
	"field-thu-relative+1": "следниот четврток",
	"dateFormatItem-GyMMMd": "dd MMM y 'г'. G",
	"field-day-relative+2": "задутре",
	"dateFormatItem-H": "HH",
	"months-standAlone-abbr": [
		"јан.",
		"фев.",
		"мар.",
		"апр.",
		"мај",
		"јун.",
		"јул.",
		"авг.",
		"септ.",
		"окт.",
		"ноем.",
		"дек."
	],
	"quarters-format-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"quarters-standAlone-wide": [
		"прво тромесечје",
		"второ тромесечје",
		"трето тромесечје",
		"четврто тромесечје"
	],
	"dateFormatItem-Gy": "y 'г'. G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"недела",
		"понеделник",
		"вторник",
		"среда",
		"четврток",
		"петок",
		"сабота"
	],
	"dateFormatItem-MMMMd": "d MMMM",
	"timeFormat-medium": "HH:mm:ss",
	"field-sun-relative+0": "оваа недела",
	"dateFormatItem-Hm": "HH:mm",
	"field-sun-relative+1": "следната недела",
	"quarters-standAlone-abbr": [
		"јан-мар",
		"апр-јун",
		"јул-сеп",
		"окт-дек"
	],
	"eraAbbr": [
		"пр.н.е.",
		"н.е."
	],
	"field-minute": "Минута",
	"field-dayperiod": "претпладне/попладне",
	"days-standAlone-abbr": [
		"нед.",
		"пон.",
		"вт.",
		"сре.",
		"чет.",
		"пет.",
		"саб."
	],
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "вчера",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "завчера",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E, d.M",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "овој петок",
	"dateFormatItem-yMMMM": "MMMM y 'г'.",
	"field-fri-relative+1": "следниот петок",
	"field-day": "ден",
	"days-format-wide": [
		"недела",
		"понеделник",
		"вторник",
		"среда",
		"четврток",
		"петок",
		"сабота"
	],
	"dateFormatItem-Mdd": "dd.M",
	"field-zone": "зона",
	"dateFormatItem-y": "y 'г'.",
	"months-standAlone-narrow": [
		"ј",
		"ф",
		"м",
		"а",
		"м",
		"ј",
		"ј",
		"а",
		"с",
		"о",
		"н",
		"д"
	],
	"field-year-relative+-1": "минатата година",
	"field-month-relative+-1": "минатиот месец",
	"dateFormatItem-hm": "h:mm a",
	"days-format-abbr": [
		"нед.",
		"пон.",
		"вт.",
		"сре.",
		"чет.",
		"пет.",
		"саб."
	],
	"dateFormatItem-yMMMd": "d MMM y 'г'.",
	"eraNames": [
		"пр.н.е.",
		"н.е."
	],
	"days-format-narrow": [
		"н",
		"п",
		"в",
		"с",
		"ч",
		"п",
		"с"
	],
	"days-standAlone-narrow": [
		"н",
		"п",
		"в",
		"с",
		"ч",
		"п",
		"с"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "Месец",
	"field-tue-relative+0": "овој вторник",
	"field-tue-relative+1": "следниот вторник",
	"dayPeriods-format-wide-am": "претпладне",
	"dateFormatItem-MMMMEd": "E d MMMM",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-relative+0": "овој понеделник",
	"field-mon-relative+1": "следниот понеделник",
	"dateFormat-short": "dd.M.yy",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"field-second": "Секунда",
	"field-sat-relative+-1": "минатата сабота",
	"dateFormatItem-yMMMEd": "E, d MMM y 'г'.",
	"field-sun-relative+-1": "минатата недела",
	"field-month-relative+0": "овој месец",
	"field-month-relative+1": "следниот месец",
	"dateFormatItem-Ed": "E, d",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "Недела",
	"dateFormat-medium": "dd.M.y",
	"field-year-relative+0": "оваа година",
	"field-week-relative+-1": "минатата седмица",
	"field-year-relative+1": "следната година",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM y 'г'. G",
	"field-mon-relative+-1": "минатиот понеделник",
	"field-week-relative+0": "оваа седмица",
	"field-week-relative+1": "следната седмица"
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/mk/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E h:mm a",
	"days-standAlone-short": [
		"нед.",
		"пон.",
		"вто.",
		"сре.",
		"чет.",
		"пет.",
		"саб."
	],
	"months-format-narrow": [
		"ј",
		"ф",
		"м",
		"а",
		"м",
		"ј",
		"ј",
		"а",
		"с",
		"о",
		"н",
		"д"
	],
	"field-second-relative+0": "сега",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "Ден во неделата",
	"dateFormatItem-yQQQ": "QQQ y 'г'.",
	"dateFormatItem-yMEd": "E, d.M.y",
	"field-wed-relative+0": "оваа среда",
	"field-wed-relative+1": "следната среда",
	"dateFormatItem-GyMMMEd": "E, dd MMM y G",
	"dateFormatItem-MMMEd": "E d MMM",
	"eraNarrow": [
		"пр. н.е.",
		"н.е."
	],
	"field-tue-relative+-1": "минатиот вторник",
	"days-format-short": [
		"нед.",
		"пон.",
		"вт.",
		"сре.",
		"чет.",
		"пет.",
		"саб."
	],
	"dateFormat-long": "dd MMMM y",
	"field-fri-relative+-1": "минатиот петок",
	"field-wed-relative+-1": "минатата среда",
	"months-format-wide": [
		"јануари",
		"февруари",
		"март",
		"април",
		"мај",
		"јуни",
		"јули",
		"август",
		"септември",
		"октомври",
		"ноември",
		"декември"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "попладне",
	"dateFormat-full": "EEEE, dd MMMM y",
	"field-thu-relative+-1": "минатиот четврток",
	"dateFormatItem-Md": "d.M",
	"dateFormatItem-yMd": "d.M.y",
	"field-era": "Ера",
	"dateFormatItem-yM": "M.y",
	"months-standAlone-wide": [
		"јануари",
		"февруари",
		"март",
		"април",
		"мај",
		"јуни",
		"јули",
		"август",
		"септември",
		"октомври",
		"ноември",
		"декември"
	],
	"timeFormat-short": "HH:mm",
	"quarters-format-wide": [
		"прво тромесечје",
		"второ тромесечје",
		"трето тромесечје",
		"четврто тромесечје"
	],
	"dateFormatItem-yQQQQ": "QQQQ y 'г'.",
	"timeFormat-long": "HH:mm:ss z",
	"field-year": "година",
	"dateFormatItem-yMMM": "MMM y 'г'.",
	"field-hour": "Час",
	"months-format-abbr": [
		"јан.",
		"фев.",
		"мар.",
		"апр.",
		"мај",
		"јун.",
		"јул.",
		"авг.",
		"септ.",
		"окт.",
		"ноем.",
		"дек."
	],
	"field-sat-relative+0": "оваа сабота",
	"field-sat-relative+1": "следната сабота",
	"timeFormat-full": "HH:mm:ss zzzz",
	"field-day-relative+0": "денес",
	"field-thu-relative+0": "овој четврток",
	"field-day-relative+1": "утре",
	"field-thu-relative+1": "следниот четврток",
	"dateFormatItem-GyMMMd": "dd MMM y G",
	"field-day-relative+2": "задутре",
	"dateFormatItem-H": "HH",
	"months-standAlone-abbr": [
		"јан.",
		"фев.",
		"мар.",
		"апр.",
		"мај",
		"јун.",
		"јул.",
		"авг.",
		"септ.",
		"окт.",
		"ноем.",
		"дек."
	],
	"quarters-format-abbr": [
		"јан-мар",
		"апр-јун",
		"јул-сеп",
		"окт-дек"
	],
	"quarters-standAlone-wide": [
		"прво тромесечје",
		"второ тромесечје",
		"трето тромесечје",
		"четврто тромесечје"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"недела",
		"понеделник",
		"вторник",
		"среда",
		"четврток",
		"петок",
		"сабота"
	],
	"dateFormatItem-MMMMd": "d MMMM",
	"timeFormat-medium": "HH:mm:ss",
	"field-sun-relative+0": "оваа недела",
	"dateFormatItem-Hm": "HH:mm",
	"field-sun-relative+1": "следната недела",
	"quarters-standAlone-abbr": [
		"јан-мар",
		"апр-јун",
		"јул-сеп",
		"окт-дек"
	],
	"eraAbbr": [
		"пр.н.е.",
		"н.е."
	],
	"field-minute": "Минута",
	"field-dayperiod": "претпладне/попладне",
	"days-standAlone-abbr": [
		"нед.",
		"пон.",
		"вт.",
		"сре.",
		"чет.",
		"пет.",
		"саб."
	],
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "вчера",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "завчера",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E, d.M",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "овој петок",
	"dateFormatItem-yMMMM": "MMMM y 'г'.",
	"field-fri-relative+1": "следниот петок",
	"field-day": "ден",
	"days-format-wide": [
		"недела",
		"понеделник",
		"вторник",
		"среда",
		"четврток",
		"петок",
		"сабота"
	],
	"dateFormatItem-Mdd": "dd.M",
	"field-zone": "зона",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"ј",
		"ф",
		"м",
		"а",
		"м",
		"ј",
		"ј",
		"а",
		"с",
		"о",
		"н",
		"д"
	],
	"field-year-relative+-1": "минатата година",
	"field-month-relative+-1": "минатиот месец",
	"dateFormatItem-hm": "h:mm a",
	"days-format-abbr": [
		"нед.",
		"пон.",
		"вт.",
		"сре.",
		"чет.",
		"пет.",
		"саб."
	],
	"dateFormatItem-yMMMd": "d MMM y 'г'.",
	"eraNames": [
		"пред нашата ера",
		"од нашата ера"
	],
	"days-format-narrow": [
		"н",
		"п",
		"в",
		"с",
		"ч",
		"п",
		"с"
	],
	"days-standAlone-narrow": [
		"н",
		"п",
		"в",
		"с",
		"ч",
		"п",
		"с"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "Месец",
	"field-tue-relative+0": "овој вторник",
	"field-tue-relative+1": "следниот вторник",
	"dayPeriods-format-wide-am": "претпладне",
	"dateFormatItem-MMMMEd": "E d MMMM",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-relative+0": "овој понеделник",
	"field-mon-relative+1": "следниот понеделник",
	"dateFormat-short": "dd.M.yy",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"field-second": "Секунда",
	"field-sat-relative+-1": "минатата сабота",
	"dateFormatItem-yMMMEd": "E, d MMM y 'г'.",
	"field-sun-relative+-1": "минатата недела",
	"field-month-relative+0": "овој месец",
	"field-month-relative+1": "следниот месец",
	"dateFormatItem-Ed": "E, d",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "Недела",
	"dateFormat-medium": "dd.M.y",
	"field-year-relative+0": "оваа година",
	"field-week-relative+-1": "минатата седмица",
	"field-year-relative+1": "следната година",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "минатиот понеделник",
	"field-week-relative+0": "оваа седмица",
	"field-week-relative+1": "следната седмица"
}
//end v1.x content
);
